@@ -178,15 +178,17 @@ html_view_accessible_ref_child (AtkObject *obj, gint i)
 	HtmlBox *html_box;
 	AtkObject *atk_child = NULL;
 
-	g_return_val_if_fail (i >= 0, 0);
-	g_return_val_if_fail (HTML_IS_VIEW_ACCESSIBLE (obj), 0);
+	if (i != 0)
+		return NULL;
+
+	g_return_val_if_fail (HTML_IS_VIEW_ACCESSIBLE (obj), NULL);
 	accessible = GTK_ACCESSIBLE (obj);
 	widget = accessible->widget;
 	if (widget == NULL)
 		/* State is defunct */
 		return NULL;
 
-	g_return_val_if_fail (HTML_IS_VIEW (widget), 0);
+	g_return_val_if_fail (HTML_IS_VIEW (widget), NULL);
 
 	html_view = HTML_VIEW (widget);
 
@@ -262,7 +264,7 @@ html_view_accessible_ref_state_set (AtkObject *obj)
 static void focus_object_destroyed (gpointer data)
 {
 	g_object_set_data (G_OBJECT (data), "gail-focus-object", NULL);
-}       
+}
 
 static void
 set_focus_object (GObject *obj,
@@ -281,4 +283,4 @@ set_focus_object (GObject *obj,
 				   (GWeakNotify) focus_object_destroyed,
 				   obj);
 	g_object_set_data (obj, "gail-focus-object", focus_obj);
-}      
+}
